<?php # $Id: serendipity_lang_en.inc.php,v 1.148 2005/04/08 22:50:24 garvinhicking Exp $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation by Torbjrn Hedberg <torbjorn@sm.luth.se>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-1');
@define('SQL_CHARSET', 'latin1');
@define('DATE_LOCALES', 'sv_SV.ISO8859-1, sv_SV.ISO-8859-1, swedish, sv, sv_SV, sv_SE.ISO8859-1, sv_SE.ISO-8859-1, sv_SE');
@define('DATE_FORMAT_ENTRY', '%A, %B %e. %Y');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'se');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Serendipity Administration');
@define('HAVE_TO_BE_LOGGED_ON', 'Du mste vara inloggad fr att se den hr sidan');
@define('WRONG_USERNAME_OR_PASSWORD', 'Du verkar ha fel anvndarnamn eller lsenord');
@define('APPEARANCE', 'Utseende');
@define('MANAGE_STYLES', 'Hantera stilar');
@define('CONFIGURE_PLUGINS', 'Konfigurera insticksmoduler');
@define('CONFIGURATION', 'Konfigurering');
@define('BACK_TO_BLOG', 'Tillbaka till bloggen');
@define('LOGIN', 'Logga in');
@define('LOGOUT', 'Logga ut');
@define('LOGGEDOUT', 'Utloggad.');
@define('CREATE', 'Skapa');
@define('SAVE', 'Spara');
@define('NAME', 'Namn');
@define('CREATE_NEW_CAT', 'Skapa ny kategori');
@define('I_WANT_THUMB', 'Jag vill anvnda miniatyren i min artikel.');
@define('I_WANT_BIG_IMAGE', 'Jag vill anvnda den strre bilden i min artikel.');
@define('I_WANT_NO_LINK', 'Jag vill visa den som en bild');
@define('I_WANT_IT_TO_LINK', 'Jag vill visa den som en lnk till denna url:');
@define('BACK', 'Tillbaka');
@define('FORWARD', 'Framt');
@define('ANONYMOUS', 'Anonymt');
@define('NEW_TRACKBACK_TO', 'Ny trackback skapad till');
@define('NEW_COMMENT_TO', 'Ny kommentar skapad till');
@define('RECENT', 'Senaste...');
@define('OLDER', 'ldre...');
@define('DONE', 'Klar');
@define('WELCOME_BACK', 'Vlkommen tillbaka,');
@define('TITLE', 'Titel');
@define('DESCRIPTION', 'Beskrivning');
@define('PLACEMENT', 'Placering');
@define('DELETE', 'Ta bort');
@define('SAVE', 'Spara');
@define('UP', 'UPP');
@define('DOWN', 'NER');
@define('ENTRIES', 'Artiklar');
@define('NEW_ENTRY', 'Ny artikel');
@define('EDIT_ENTRIES', 'Redigera artiklar');
@define('CATEGORIES', 'Kategorier');
@define('WARNING_THIS_BLAHBLAH', "VARNING:\\nDetta kan ta lng tid om det r mnga bilder utan miniatyrer.");
@define('CREATE_THUMBS', 'Bygg om miniatyrer');
@define('MANAGE_IMAGES', 'Hantera bilder');
@define('NAME', 'Namn');
@define('EMAIL', 'E-post');
@define('HOMEPAGE', 'Hemsida');
@define('COMMENT', 'Kommentar');
@define('REMEMBER_INFO', 'Kom ihg information? ');
@define('SUBMIT_COMMENT', 'Spara kommentar');
@define('NO_ENTRIES_TO_PRINT', 'Ingen artikel att skriva ut');
@define('COMMENTS', 'Kommentarer');
@define('ADD_COMMENT', 'Lgg till kommentar');
@define('NO_COMMENTS', 'Inga kommentarer');
@define('POSTED_BY', 'Skapad av');
@define('ON', 'den');
@define('A_NEW_COMMENT_BLAHBLAH', 'En ny kommentar har skrivits i din blogg "%s", till artikeln med namnet "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'En ny trackback har gjorts till din blogg-artikel med namnet "%s".');
@define('NO_CATEGORY', 'Ingen kategori');
@define('ENTRY_BODY', 'Innehll artikel');
@define('EXTENDED_BODY', 'Utkat innehll');
@define('CATEGORY', 'Kategori');
@define('EDIT', 'Redigera');
@define('NO_ENTRIES_BLAHBLAH', 'Inga artiklar hittade fr skningen %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Din skning efter %s gav %s resultat:');
@define('IMAGE', 'Bild');
@define('ERROR_FILE_NOT_EXISTS', 'Fel: Det gamla filnamnet finns inte!');
@define('ERROR_FILE_EXISTS', 'Fel: Filnamnet finns redan, vlj ett annat!');
@define('ERROR_SOMETHING', 'Fel: Ngonting r fel.');
@define('ADDING_IMAGE', 'Lgger till bild...');
@define('THUMB_CREATED_DONE', 'Miniatyr skapad.<br/>Klar.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Fel: Filen finns redan i din dator!');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Ett oknt fel intrffade och filen laddades inte upp. Filstorleken r kanske strre n vad som tillts av din serverinstallation. Kolla med din tjnsteleverantr eller ndra i filen php.ini fr att tillta uppladdning av strre filer.');
@define('GO', 'Kr!');
@define('NEWSIZE', 'Ny storlek: ');
@define('RESIZE_BLAHBLAH', '<b>ndra storlek p %s</b><p>');
@define('ORIGINAL_SIZE', 'Ursprunglig storlek: <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hr kan du anpassa bildstorleken. Om du vill ndra storlek proportionellt, ndra bara ett vrde i ngot av de tv flten och tryck p TAB - D ndras  automatiskt storleken automatiskt s att bildens proportioner bibehlls</p>');
@define('QUICKJUMP_CALENDAR', 'Snabbkalender');
@define('QUICKSEARCH', 'Snabbsk');
@define('SEARCH_FOR_ENTRY', 'Sk efter artikel');
@define('ARCHIVES', 'Arkiv');
@define('BROWSE_ARCHIVES', 'Blddra i mnadsarkivet');
@define('TOP_REFERRER', 'Vanligaste hnvisare');
@define('SHOWS_TOP_SITES', 'Vanligaste sajterna som lnkat till din blogg');
@define('TOP_EXITS', 'Vanligaste utgngar');
@define('SHOWS_TOP_EXIT', 'Visar de vanligaste lnkarna som anvnts ut frn din blogg');
@define('SYNDICATION', 'Syndikering');
@define('SHOWS_RSS_BLAHBLAH', 'Visar RSS-syndikeringslnkar');
@define('ADVERTISES_BLAHBLAH', 'Visar ursprunget till din blogg');
@define('HTML_NUGGET', 'HTML-snutt');
@define('HOLDS_A_BLAHBLAH', 'Innehller en liten snutt HTML i din sidonavigator');
@define('TITLE_FOR_NUGGET', 'Titel p HTML-snutten');
@define('THE_NUGGET', 'HTML-snutten!');
@define('SYNDICATE_THIS_BLOG', 'Syndikera denna blogg');
@define('YOU_CHOSE', 'Du valde %s');
@define('IMAGE_ROTATE_LEFT', 'Rotera bilden 90 grader motsols');
@define('IMAGE_ROTATE_RIGHT', 'Rotera bilden 90 grader medsols');
@define('IMAGE_SIZE', 'Bildstorlek');
@define('IMAGE_AS_A_LINK', 'Infoga bild');
@define('POWERED_BY', 'Baseras p');
@define('TRACKBACKS', 'Trackbacks');
@define('TRACKBACK', 'Trackback');
@define('NO_TRACKBACKS', 'Inga trackbacks');
@define('TOPICS_OF', 'mnen frn');
@define('VIEW_FULL', 'Visa alla');
@define('VIEW_TOPICS', 'Visa mnen');
@define('AT', 'kl');
@define('SET_AS_TEMPLATE', 'Anvnd som mall');
@define('IN', 'i');
@define('EXCERPT', 'Utdrag');
@define('TRACKED', 'Sprad');
@define('LINK_TO_ENTRY', 'Lnk till artikel');
@define('LINK_TO_REMOTE_ENTRY', 'Lnk till extern artikel');
@define('IP_ADDRESS', 'IP-adress');
@define('USER', 'Anvndare');
@define('THUMBNAIL_USING_OWN', 'Anvnder %s som miniatyr pga. dess storlek.');
@define('THUMBNAIL_FAILED_COPY', 'Ville anvnda %s som sin egen miniatyr men kunde inte kopiera den!');
@define('AUTHOR', 'Frfattare');
@define('LAST_UPDATED', 'Senast uppdaterad');
@define('TRACKBACK_SPECIFIC', 'Trackback URI fr denna artikel');
@define('DIRECT_LINK', 'Direktlnk till denna artikel');
@define('COMMENT_ADDED', 'Din kommentar r tillagd. ');
@define('COMMENT_ADDED_CLICK', 'Klicka %shr fr att komma tillbaka%s till kommentarerna, och %shr fr att stnga%s detta fnster.');
@define('COMMENT_NOT_ADDED_CLICK', 'Klicka %shr fr att komma tillbaka%s till kommentarerna, och %shr fr att stnga%s detta fnster.');
@define('COMMENTS_DISABLE', 'Tillt inte kommentarer fr denna artikel');
@define('COMMENTS_ENABLE', 'Tillt kommentarer fr denna artikel');
@define('COMMENTS_CLOSED', 'Frfattaren tillter inte kommentarer till denna artikel');
@define('EMPTY_COMMENT', 'Din kommentar innehller ingenting, %sg tillbaks%s och frsk igen');
@define('ENTRIES_FOR', 'Artiklar frn %s');
@define('DOCUMENT_NOT_FOUND', 'Dokumentet %s hittades inte.');
@define('USERNAME', 'Anvndarnamn');
@define('PASSWORD', 'Lsenord');
@define('AUTOMATIC_LOGIN', 'Spara information');
@define('SERENDIPITY_INSTALLATION', 'Installation av Serendipity');
@define('LEFT', 'Vnster');
@define('RIGHT', 'Hger');
@define('HIDDEN', 'Dold');
@define('REMOVE_TICKED_PLUGINS', 'Ta bort markerade insticksmoduler');
@define('SAVE_CHANGES_TO_LAYOUT', 'Spara layoutndringar');
@define('COMMENTS_FROM', 'Kommentarer frn');
@define('ERROR', 'Fel');
@define('ENTRY_SAVED', 'Din artikel har sparats');
@define('DELETE_SURE', 'Vill du verkligen ta bort #%s permanent?');
@define('NOT_REALLY', 'Nej');
@define('DUMP_IT', 'Ja');
@define('RIP_ENTRY', 'Artikel #%s borttagen.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Kategori #%s borttagen. Gamla artiklar flyttade till kategori #%s.');
@define('CATEGORY_DELETED', 'Kategori #%s borttagen.');
@define('INVALID_CATEGORY', 'Ingen kategori angiven fr borttagning');
@define('CATEGORY_SAVED', 'Kategori sparad');
@define('SELECT_TEMPLATE', 'Vlj vilken mall du vill anvnda fr din blogg');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Artiklarna kunde inte lggas till!');
@define('MT_DATA_FILE', 'Movable Type datafil');
@define('FORCE', 'Tvinga');
@define('CREATE_AUTHOR', 'Skapa frfattare \'%s\'.');
@define('CREATE_CATEGORY', 'Skapa kategori \'%s\'.');
@define('MYSQL_REQUIRED', 'Du mste ha MySQL extension fr att utfra denna operation.');
@define('COULDNT_CONNECT', 'Kunde inte ansluta till MySQL-databasen: %s.');
@define('COULDNT_SELECT_DB', 'Hittade inte databas: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Hittade inte anvndarinformation: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Hittade inte kategoriinformation: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Hittade inte artikelinformation: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Hittade inte kommentarinformation: %s.');
@define('YES', 'Ja');
@define('NO', 'Nej');
@define('USE_DEFAULT', 'Frvalt');
@define('CHECK_N_SAVE', 'Vlj &amp; spara');
@define('DIRECTORY_WRITE_ERROR', 'Kan inte skriva till katalogen %s. Kontrollera rttigheter.');
@define('DIRECTORY_CREATE_ERROR', 'Katalogen %s finns inte och kunde inte skapas. Skapa katalogen manuellt');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; kr <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Kunde inte kra %s binrfil');
@define('FILE_WRITE_ERROR', 'Kan inte skriva till filen %s.');
@define('FILE_CREATE_YOURSELF', 'Skapa filen sjlv eller kontrollera rttigheter');
@define('COPY_CODE_BELOW', '<br />* Kopiera koden nedan och lgg den i %s i din %s mapp:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'ndra www till den anvndare apache kr som (t.ex. nobody eller www).');
@define('BROWSER_RELOAD', 'Nr du har gjort detta, vlj "Uppdatera" eller motsvarande i din webblsare.');
@define('DIAGNOSTIC_ERROR', 'Vi hittade ngra fel nr vi krde diagnostik p din inmatade information:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity r inte installerad n. Var god <a href="%s">installera</a> nu.');
@define('INCLUDE_ERROR', 'Serendipity fel: kunde inte inkludera %s - avslutar.');
@define('DATABASE_ERROR', 'Serendipity fel: kunde inte ansluta till databas - avslutar.');
@define('CREATE_DATABASE', 'Skapar standardinstllning fr databas...');
@define('ATTEMPT_WRITE_FILE', 'Frsker skriva filen %s...');
@define('WRITTEN_N_SAVED', 'Konfiguration sparad');
@define('IMAGE_ALIGNMENT', 'Bildjustering');
@define('ENTER_NEW_NAME', 'Ange det nya namnet fr: ');
@define('RESIZING', 'ndrar storlek');
@define('RESIZE_DONE', 'Klar (bt storlek p %s bilder).');
@define('SYNCING', 'Synkroniserar databasen med bildkatalogen');
@define('SYNC_DONE', 'Klar (synkroniserade %s bilder).');
@define('FILE_NOT_FOUND', 'Kunde inte hitta filen <b>%s</b>, kanske r den redan borttagen?');
@define('ABORT_NOW', 'Avbryt nu');
@define('REMOTE_FILE_NOT_FOUND', 'Kunde inte hitta filen p den externa servern, r du sker p att URL: <b>%s</b> r helt korrekt?');
@define('FILE_FETCHED', '%s hmtad som %s');
@define('FILE_UPLOADED', 'Filen %s uppladdad som %s');
@define('WORD_OR', 'Eller');
@define('SCALING_IMAGE', 'Skalar %s till %s x %s px');
@define('KEEP_PROPORTIONS', 'Behll proportioner');
@define('REALLY_SCALE_IMAGE', 'Vill du verkligen ndra storlek? Detta kan inte ngras!');
@define('TOGGLE_ALL', 'Visa/dlj alla');
@define('TOGGLE_OPTION', 'Visa/dlj val');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Prenumerera p denna artikel');
@define('UNSUBSCRIBE_OK', "%s har nu avslutat prenumeration p denna artikel");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Ny kommentar till prenumererad artikel "%s"');
@define('SUBSCRIPTION_MAIL', "Hej %s,\n\nEn ny kommentar r gjord till artikeln du fljer hos \"%s\", vid namn \"%s\"\nKommentarens skapare r: %s\n\nDu kan hitta artikeln hr: %s\n\nDu kan avsluta prenumerationen genom att klicka p denna lnk: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Hej %s,\n\nEn ny trackback r gjord till artikeln du fljer hos \"%s\", vid namn \"%s\"\nSkapare r: %s\n\nDu kan hitta artikeln hr: %s\n\nDu kan avsluta prenumerationen genom att klicka p denna lnk: %s\n");
@define('SIGNATURE', "\n-- \n%s bygger p Serendipty.\nDen bsta bloggen, och du kan ocks anvnda den.\nKolla <http://s9y.org> fr att f veta hur.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 matning');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 matning');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 matning');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 kommentarer');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 matning');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Flt "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Flt "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Bild fr RSS matning');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Bildbredd');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Bildhjd');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'E-post-adress till webmaster, om tillgnglig. (tom: dold) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'E-mail-adress till ansvarig utgivare, om tillgnglig. (tom: dold) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL till en bild i GIF/JPEG/PNG format, om  tillgnglig. (tom: serendipity-logga)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'i pixels, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'i pixels, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Flt "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Antal minuter som din blogg maximalt br cache-lagras av andra sajter/applikationer (tom: dold) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Flt "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Skall flet "pubDate" ing i en RSS-kanal fr att visa datumet p senaste artikeln?');
@define('CONTENT', 'Innehll');
@define('TYPE', 'Typ');
@define('DRAFT', 'Utkast');
@define('PUBLISH', 'Publicera');
@define('PREVIEW', 'Frhandsgranska');
@define('DATE', 'Datum');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Varning: Datumet du angav var ogiltigt. Det mste skrivas i formatet -MM-DD TT:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Visar listan med kategorier.');
@define('ALL_AUTHORS', 'Alla frfattare');
@define('CATEGORIES_TO_FETCH', 'Kategorier att hmta');
@define('CATEGORIES_TO_FETCH_DESC', 'Hmta kategorier frn vilken frfattare?');
@define('PAGE_BROWSE_ENTRIES', 'Sida %s av %s, sammanlagt %s artiklar');
@define('PREVIOUS_PAGE', 'fregende sida');
@define('NEXT_PAGE', 'nsta sida');
@define('ALL_CATEGORIES', 'Alla kategorier');
@define('DO_MARKUP', 'Utfr Markup Transformations');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Datumformatering');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formatet p artikelns verkliga datum, med hjlp PHPs strftime() variabler. (Default: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Kunde inte ppna mallfil. Uppdatera Serendipity!');
@define('ADVANCED_OPTIONS', 'Utkade instllningar');
@define('EDIT_ENTRY', 'Redigera artikel');
@define('HTACCESS_ERROR', 'Fr att kontrollera din lokala webbserver-installation mste Serendipity kunna skriva till filen ".htaccess". Detta gick inte pga fel rttigheter. Justera rttigheterna s hr: <br />&nbsp;&nbsp;%s<br />ladda om sidan.');
@define('SIDEBAR_PLUGINS', 'Sid-navigator Plugins');
@define('EVENT_PLUGINS', 'Hndelse-plugin');
@define('SORT_ORDER', 'Sorteringordning');
@define('SORT_ORDER_NAME', 'Filnamn');
@define('SORT_ORDER_EXTENSION', 'Filndelse');
@define('SORT_ORDER_SIZE', 'Filstorlek');
@define('SORT_ORDER_WIDTH', 'Bildbredd');
@define('SORT_ORDER_HEIGHT', 'Bildhjd');
@define('SORT_ORDER_DATE', 'Uppladdningsdatum');
@define('SORT_ORDER_ASC', 'Stigande');
@define('SORT_ORDER_DESC', 'Fallande');
@define('THUMBNAIL_SHORT', 'Mini');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Applicera textdekoration p %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Brjan av veckan');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Din nuvarande version av Serendipity r %s. Det verkar som om du frsker uppgradera till %s, s du behver <a href="%s">klicka hr</a> fr att fortstta uppgraderingsprocessen.');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Hej, och vlkommen till Serendipitys uppgraderings-agent.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Jag r hr fr att hjlpa dig uppgradera din installation av Serendipity %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'Du ser det hr meddelandet fr att du just har installerat Serendipity %s men nnu inte uppgraderat din databas fr att passa den hr versionen');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Databasuppdateringar (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Jag har hittat fljande .sql-filer som behver kras innan du kan fortstta anvnda Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Versionsspecifika uppgifter');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Inga versionsspecifika uppgifter hittade');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Skall jag utfra ovanstende uppgifter?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Nej, jag kr dem manuellt');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Ja, tack');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Det ser ut som om du inte behver kra ngra uppgraderingar');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity uppgraderad');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Du har struntat i uppgraderingsfasen av Serendipity, se till att databasen r korrekt installerad, och att schemalagda uppgifter krs');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Din Serendipity-installation r nu uppgraderad till version %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Du kan g tillbaks till din blogg genom att klicka %shr%s');
@define('MANAGE_USERS', 'Hantera anvndare');
@define('CREATE_NEW_USER', 'Skapa ny anvndare');
@define('CREATE_NOT_AUTHORIZED', 'Du kan inte ndra anvndare med samma anvndarniv som dig sjlv');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Du kan inte skapa anvndare med hgre anvndarniv n dig sjlv');
@define('CREATED_USER', 'En ny anvndare %s har skapats');
@define('MODIFIED_USER', 'Egenskaperna fr anvndare %s har ndrats');
@define('USER_LEVEL', 'Anvndarniv');
@define('DELETE_USER', 'Du r p vg att ta bort anvndare #%d %s. r du helt sker? Det kommer att gra att inga artiklar skrivna av honom/henne kan visas.');
@define('DELETED_USER', 'Anvndare #%d %s borttagen.');
@define('LIMIT_TO_NUMBER', 'Hur mnga poster skall visas?');
@define('ENTRIES_PER_PAGE', 'artiklar per sida');
@define('XML_IMAGE_TO_DISPLAY', 'XML-knapp');
@define('XML_IMAGE_TO_DISPLAY_DESC','Lnkar till XML-matningar kommer att visas med denna bild. Lmna tomt fr standardbild, skriv \'none\' fr att inaktivera.');

@define('DIRECTORIES_AVAILABLE', 'Klicka i listan ver tillgngliga underkataloger fr att skapa en ny katalog.');
@define('ALL_DIRECTORIES', 'Alla kataloger');
@define('MANAGE_DIRECTORIES', 'Alla kataloger');
@define('DIRECTORY_CREATED', 'Katalogen <strong>%s</strong> har skapats.');
@define('PARENT_DIRECTORY', 'verliggande katalog');
@define('CONFIRM_DELETE_DIRECTORY', 'r du sker p att du vill ta bort hela innehllet i katalogen %s?');
@define('ERROR_NO_DIRECTORY', 'Fel: Katalogen %s finns inte');
@define('CHECKING_DIRECTORY', 'Kollar filer i katalogen %s');
@define('DELETING_FILE', 'Tar bort filen %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Katalogen r inte tom och kan drfr inte tas bort. Markera kryssrutan "force deletion" om du vill ta bort dessa kataloger. De filer som finns r:');
@define('DIRECTORY_DELETE_FAILED', 'Det gick inte att ta bort katalogen %s. Kolla rttigheter eller meddelandena hr ovanfr.');
@define('DIRECTORY_DELETE_SUCCESS', 'Katalogen %s borttagen.');
@define('SKIPPING_FILE_EXTENSION', 'Hoppar ver fil: Saknas filndelse p %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Hoppar ver fil: %s r inte lsbar.');
@define('FOUND_FILE', 'Hittad ny/ndrad fil: %s.');
@define('ALREADY_SUBCATEGORY', '%s r redan en underkatalog till %s.');
@define('PARENT_CATEGORY', 'verordnad kategori');
@define('IN_REPLY_TO', 'Som svar till');
@define('TOP_LEVEL', 'versta nivn');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s matning');
@define('PERMISSIONS', 'Rttigheter');
@define('SETTINGS_SAVED_AT', 'De nya instllningarna har sparats p %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Databasinstllningar');
@define('INSTALL_CAT_DB_DESC', 'Hr fyller du i alla dina databasuppgifter. Serendipity behver dessa fr att fungera');
@define('INSTALL_DBTYPE', 'Databastyp');
@define('INSTALL_DBTYPE_DESC', 'Databastyp');
@define('INSTALL_DBHOST', 'Databasvrd');
@define('INSTALL_DBHOST_DESC', 'Vrdnamnet fr din databasserver');
@define('INSTALL_DBUSER', 'Databasanvndare');
@define('INSTALL_DBUSER_DESC', 'Anvndarnamnet som anvnds fr att ansluta till din databas');
@define('INSTALL_DBPASS', 'Databaslsenord');
@define('INSTALL_DBPASS_DESC', 'Lsenordet som hr till ovanstende anvndarnamn');
@define('INSTALL_DBNAME', 'Databasnamn');
@define('INSTALL_DBNAME_DESC', 'Namnet p din databas');
@define('INSTALL_DBPREFIX', 'Databasens tabellprefix');
@define('INSTALL_DBPREFIX_DESC', 'Prefixet fr tabellnamnen, till exempel serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Skvgar');
@define('INSTALL_CAT_PATHS_DESC', 'Olka skvgar till ndvndiga mappar och filer. Glm inte efterfljande snedstreck fr kataloger!');
@define('INSTALL_FULLPATH', 'Fullstndig skvg');
@define('INSTALL_FULLPATH_DESC', 'Den absoluta (fullstndiga) skvgen till din Serendipity-installation');
@define('INSTALL_UPLOADPATH', 'Skvg fr uppladdning');
@define('INSTALL_UPLOADPATH_DESC', 'Allt uppladdat material hamnar hr, relativt till \'Komplett skvg\' - oftast \'uploads/\'');
@define('INSTALL_RELPATH', 'Relativ skvg');
@define('INSTALL_RELPATH_DESC', 'Skvg till Serendipity fr din webblsare. Oftast \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Relativ mallskvg');
@define('INSTALL_RELTEMPLPATH_DESC', 'Skvg till mappen som innehller dina mallar - Relativt till \'Relativ skvg\'');
@define('INSTALL_RELUPLOADPATH', 'Relativ skvg fr uppladdat material');
@define('INSTALL_RELUPLOADPATH_DESC', 'Skvg till ditt uppladdade material fr din webblsare - Relativt till \'Relativ skvg\'');
@define('INSTALL_URL', 'URL till blogg');
@define('INSTALL_URL_DESC', 'Bas-URL till din Serendipity-installation');
@define('INSTALL_INDEXFILE', 'Index-fil');
@define('INSTALL_INDEXFILE_DESC', 'Namnet p din index-fil fr Serendipity');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', 'Allmnna instllningar');
@define('INSTALL_CAT_SETTINGS_DESC', 'Anpassa hur Serendipity beter sig');
@define('INSTALL_USERNAME', 'Admin anvndarnamn');
@define('INSTALL_USERNAME_DESC', 'nvndarnamn fr administratrsinloggning');
@define('INSTALL_PASSWORD', 'Admin lsenord');
@define('INSTALL_PASSWORD_DESC', 'Lsenord fr administratrsinloggning');
@define('INSTALL_EMAIL', 'Admin e-post');
@define('INSTALL_EMAIL_DESC', 'E-post till bloggadministratren');
@define('INSTALL_SENDMAIL', 'Skicka mail till admin?');
@define('INSTALL_SENDMAIL_DESC', 'Vill du f e-post nr kommentarer skapas till dina artiklar?');
@define('INSTALL_SUBSCRIBE', 'Lt anvndare prenumerera p dina artiklar?');
@define('INSTALL_SUBSCRIBE_DESC', 'Tillt anvndare att prenumera p en artikel och drigenom f ett mail nr kommentarer grs till artikeln');
@define('INSTALL_BLOGNAME', 'Bloggens namn');
@define('INSTALL_BLOGNAME_DESC', 'Bloggens titel');
@define('INSTALL_BLOGDESC', 'Bloggens beskrivning');
@define('INSTALL_BLOGDESC_DESC', 'Din blogg-beskrivning');
@define('INSTALL_LANG', 'Sprk');
@define('INSTALL_LANG_DESC', 'Ange sprk fr din blogg');

/* APPEARANCE AND OPTIONS */
@define('INSTALL_CAT_DISPLAY', 'Utseende och egenskaper');
@define('INSTALL_CAT_DISPLAY_DESC', 'Anpassa hur Serendipity ser ut');
@define('INSTALL_WYSIWYG', 'Anvnd WYSIWYG-editorn');
@define('INSTALL_WYSIWYG_DESC', 'Vill du anvnda WYSIWYG editorn? (Fungerar med IE5+, delvis i Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Tvinga till XHTML 1.1 standard');
@define('INSTALL_XHTML11_DESC', 'Vill du tvinga till XHTML 1.1 standard (kan orsaka problem fr back-/frontend p ldre 4:e generations webblsare)');
@define('INSTALL_POPUP', 'Tillt anvndning av popup-fnster');
@define('INSTALL_POPUP_DESC', 'Vill du anvnda popup-fnster fr kommentarer, trackbacks et al?');
@define('INSTALL_EMBED', 'r Serendipity inbddad?');
@define('INSTALL_EMBED_DESC', 'Om du vill bdda in Serendipity i en vanlig webbsida ska du vlja detta fr att enbart generera sidinnehllet. Du kan anvnda indexFile-alternativet fr att anvnda en wrapper-klass dr du skulle ha placerat det vanliga webbsidehuvudet. Ls README-filen fr mer information!');
@define('INSTALL_TOP_AS_LINKS', 'Visa vanligaste utgngar/hnvisare som lnkar?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"Nej": Utgngar och hnvisare visas som vanlig text fr att frhindra google-spam. "Ja": Utgngar och hnvisare visas som lnkar. "Frvalt": Anvnd globala konfigureringsinstllningar (rekommenderas).');
@define('INSTALL_BLOCKREF', 'Blockerade hnvisare');
@define('INSTALL_BLOCKREF_DESC', 'Finns det ngra speciella vrdnamn som du inte vill ska visas i hnvisningslistan? En separat lista med vrdnamn med \';\' och notera att vrdnamnet blockeras med delstrngsmatchning!');
@define('INSTALL_REWRITE', 'URL Rewriting');
@define('INSTALL_REWRITE_DESC', 'Vlj vilka regler du vill anvnda fr att generera URLer. Genom att anvnda rewrite-regler kan du gra snygga URLer till din blogg och gra den lttare att indexera fr spiders som google. Webbservern mste stdja antingen mod_rewrite eller "AllowOverride All" fr din Serendipity-katalog. Den frvalda instllningen r auto-detected');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', 'Instllningar fr bildkonvertering');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Ange allmn information om hur Serendipity skall hantera bilder');
@define('INSTALL_IMAGEMAGICK', 'Anvnd ImageMagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Har du ImageMagick installerat och vill du anvnda det fr att ndra bildstorlekar?');
@define('INSTALL_IMAGEMAGICKPATH', 'Skvg till konverteringsprogram');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Komplett skvg & namn fr ditt ImageMagick konverteringsprogram');
@define('INSTALL_THUMBSUFFIX', 'Miniatyrbildssuffix');
@define('INSTALL_THUMBSUFFIX_DESC', 'Miniatyrer kommer att dpas enligt fljande format: original.[suffix].ext');
@define('INSTALL_THUMBWIDTH', 'Miniatyrbildsdimensioner');
@define('INSTALL_THUMBWIDTH_DESC', 'Statisk max-bredd fr auto-genererade miniatyrbilder');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Din personliga information');
@define('USERCONF_CAT_PERSONAL_DESC', 'ndra din personliga information');
@define('USERCONF_USERNAME', 'Ditt anvndarnamn');
@define('USERCONF_USERNAME_DESC', 'Anvndarnamnet fr att logga in till denna blogg');
@define('USERCONF_PASSWORD', 'Ditt lsenord');
@define('USERCONF_PASSWORD_DESC', 'Lsenordet du vill anvnda fr att logga in till denna blogg');
@define('USERCONF_EMAIL', 'Din e-post adress');
@define('USERCONF_EMAIL_DESC', 'Din personliga e-post adress');
@define('USERCONF_SENDCOMMENTS', 'Skicka kommentar-meddelanden?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Vill du f e-post nr kommentarer skapas till dina artiklar?');
@define('USERCONF_SENDTRACKBACKS', 'Skicka trackback-meddelanden');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Vill du f e-post nr trackbacks skapas till dina artiklar?');
@define('USERCONF_ALLOWPUBLISH', 'Rttigheter: Publicera artiklar?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Har denna anvndare rtt att publicera artiklar?');
@define('SUCCESS', 'Framgng');
@define('POWERED_BY_SHOW_TEXT', 'Visa "Serendipity" som text');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Kommer att visa "Serendipity Weblog" som text');
@define('POWERED_BY_SHOW_IMAGE', 'Visa "Serendipity" med en logga');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Visar Serendipitys logga');
@define('PLUGIN_ITEM_DISPLAY', 'Var skall denna post visas?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Endast utvidgad artikel');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Endast versiktssida');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Alltid');
@define('RSS_IMPORT_CATEGORY', 'Anvnd denna kategori fr icke matchande importerade artiklar');

@define('COMMENTS_WILL_BE_MODERATED', 'Kommentarer mste godknnas innan de visas.');
@define('YOU_HAVE_THESE_OPTIONS', 'Du har fljande alternativ:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Varning: Den hr kommentaren mste frst godknnas');
@define('DELETE_COMMENT', 'Ta bort kommentar');
@define('APPROVE_COMMENT', 'Godknn kommentar');
@define('REQUIRES_REVIEW', 'Krver granskning');
@define('COMMENT_APPROVED', 'Komentaren #%s har blivit godknd');
@define('COMMENT_DELETED', 'Kommentare #%s har blivit borttagen');
@define('COMMENTS_MODERATE', 'Kommentarer & trackbacks till denna artikel kommer att granskning innan de visas');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Varning: Denna trackback krver godknnande innan den visas');
@define('DELETE_TRACKBACK', 'Ta bort trackback');
@define('APPROVE_TRACKBACK', 'Godknn trackback');
@define('TRACKBACK_APPROVED', 'Trackback #%s har blivit godknd');
@define('TRACKBACK_DELETED', 'Trackback #%s har tagits bort');
@define('VIEW', 'Visa');
@define('COMMENT_ALREADY_APPROVED', 'Kommentaren #%s verkar ha blivit godknd redan');
@define('COMMENT_EDITED', 'Den valda kommentaren har redigerats');
@define('HIDE', 'Dlj');
@define('VIEW_EXTENDED_ENTRY', 'Fortstt lsa "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Denna lnk r inte avsedd att klickas p. Den innehller en trackback-URI fr denna artikel. Du kan anvnda denna URI fr att skicka ping- & trackbacks frn din egen blogg till denna artikel. Fr att kopiera lnken, hgerklicka och vlj "Kopiera lnk" i Internet Explorer eller "Kopiera lnk ...." i Mozilla.');
@define('PLUGIN_SUPERUSER_HTTPS', 'Anvnd https vid inloggning');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Gr att inloggningslnken pekar p en https-URI. Din webbserver behver ha std fr https!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Gr externa lnkar klickbara?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"Nej": Okontrollerade externa lnkar (Topputgngar, topphnvisare, anvndarkommentarer) visas inte eller visas som vanlig text dr s r lmpligt, fr att frhindra google spam (rekommenderas). "Ja": Okontrollerade externa lnkar visas som hyperlnkar. Detta kan sidosttas inom sidomenykonfigrationen!');
@define('PAGE_BROWSE_COMMENTS', 'Sida %s av %s, sammanlagt %s kommentarer');
@define('FILTERS', 'Filter');
@define('FIND_ENTRIES', 'Sk artiklar');
@define('FIND_COMMENTS', 'Sk kommentarer');
@define('FIND_MEDIA', 'Sk media');
@define('FILTER_DIRECTORY', 'Katalog');
@define('SORT_BY', 'Sortera utefter');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Ingen trackback skickad: Kunde inte ppna anslutning till %s p port %d');
@define('MEDIA', 'Media');
@define('MEDIA_LIBRARY', 'Mediebibliotek');
@define('ADD_MEDIA', 'Lgg till media');
@define('ENTER_MEDIA_URL', 'Ange en URL till en fil att hmta:');
@define('ENTER_MEDIA_UPLOAD', 'Vlj en fil du vill ladda upp:');
@define('SAVE_FILE_AS', 'Spara filen som:');
@define('STORE_IN_DIRECTORY', 'Lagra i fljande katalog: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>Lgg till en fil till ditt mediebibliotek:</b><p>Hr kan du ladda upp mediefiler, eller be mig att hmta dem frn en plats p webben! Om du inte har ngon lmplig bild, <a href="http://images.google.com" target="_blank">leta efter bilder p google</a> som passar dina tankar, resultaten r ofta anvndbara och roliga :) Men var frsiktig, de flesta bilder r skyddade av upphovsrtten, s du mste frga innan du anvnder dem.</p><p><b>Vlj metod:</b></p><br/>');
@define('MEDIA_RENAME', 'Dp om denna fil');
@define('IMAGE_RESIZE', 'ndra storlek denna bild');
@define('MEDIA_DELETE', 'Ta bort denna fil');
@define('FILES_PER_PAGE', 'Filer per sida');
@define('CLICK_FILE_TO_INSERT', 'Klicka p filen du vill infoga:');
@define('SELECT_FILE', 'Vlj fil att infoga');
@define('MEDIA_FULLSIZE', 'Full storlek');
@define('CALENDAR_BOW_DESC', 'Veckodag som brjar vecka. Standardinstllning r mndag');
@define('SUPERUSER', 'Administrera bloggen');
@define('ALLOWS_YOU_BLAHBLAH', 'Ger en lnk i sid-navigatorn till blogg-administrationen');
@define('CALENDAR', 'Kalender');
@define('SUPERUSER_OPEN_ADMIN', 'Till administrationen');
@define('SUPERUSER_OPEN_LOGIN', 'Till inloggningssidan');
@define('INVERT_SELECTIONS', 'Invertera val');
@define('COMMENTS_DELETE_CONFIRM', 'r du sker p att du vill ta bort de valda kommentarerna?');
@define('COMMENT_DELETE_CONFIRM', 'r du sker p att du vill ta bort kommentaren #%d, skriven av %s?');
@define('DELETE_SELECTED_COMMENTS', 'Ta bort valda kommmentarer');
@define('VIEW_COMMENT', 'Visa kommentar');
@define('VIEW_ENTRY', 'Visa artikel');
@define('DELETE_FILE_FAIL' , 'Kan inte ta bort filen <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Ta bort miniatyren <b>%s</b>');
@define('DELETE_FILE', 'Ta bort filen <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Du hller p ta bort <b>%s</b><br />Om du anvnder den hr filen i ngon av dina artiklar fr du lnk-/bildfel<br />Vill du fortfarande ta bort den?<br /><br />');
@define('TRACKBACK_SENDING', 'Skickar trackback till URI %s...');
@define('TRACKBACK_SENT', 'Trackback fungerade');
@define('TRACKBACK_FAILED', 'Trackback misslyckades: %s');
@define('TRACKBACK_NOT_FOUND', 'Ingen trackback-URI hittad.');
@define('TRACKBACK_URI_MISMATCH', 'Den automatiskt funna trackback-URI:n matchar inte vr ml-URI.');
@define('TRACKBACK_CHECKING', 'Kollar <u>%s</u> mjliga trackbacks...');
@define('TRACKBACK_NO_DATA', 'Mlet innehll ingen data');
@define('TRACKBACK_SIZE', 'Ml-URI versker max-storlek p %s bytes.');
@define('COMMENTS_VIEWMODE_THREADED', 'Trdad');
@define('COMMENTS_VIEWMODE_LINEAR', 'Rak');
@define('DISPLAY_COMMENTS_AS', 'Visa kommentarer som');
@define('COMMENTS_FILTER_SHOW', 'Visa');
@define('COMMENTS_FILTER_ALL', 'Alla');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Bara godknda');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Vntar p godknnande');
@define('RSS_IMPORT_BODYONLY', 'Lgg all importerad text i "innehll"-sektionen och splittra inte upp den i "utvidgad artikel"-sektionen.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Visa fullstndiga artiklar med utvidgat innehll i RSS-matningen');
@define('WEEK', 'Vecka');
@define('WEEKS', 'Veckor');
@define('MONTHS', 'Mnader');
@define('DAYS', 'Dagar');
@define('ARCHIVE_FREQUENCY', 'Kalenderpost-frekvens');
@define('ARCHIVE_FREQUENCY_DESC', 'Kalenderintervall mellan varje post i listan');
@define('ARCHIVE_COUNT', 'Antalet poster i listan');
@define('ARCHIVE_COUNT_DESC', 'Totalt antal mnader, veckor eller dagar att visa');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Hr nedan r en lista med installerade insticksmoduler');
@define('SIDEBAR_PLUGIN', 'Insticksmodul fr sid-navigatorn');
@define('EVENT_PLUGIN', 'Hndelsebaserad insticksmodul');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Klicka hr fr att installera en ny %s');
@define('VERSION', 'Version');
@define('INSTALL', 'Installera');
@define('ALREADY_INSTALLED', 'Redan installerad');
@define('SELECT_A_PLUGIN_TO_ADD', 'Vlj den instickmodul som du vill installera');
@define('INSTALL_OFFSET', 'Kompensation fr serverklocka');
@define('STICKY_POSTINGS', 'Spikade artiklar');
@define('INSTALL_FETCHLIMIT', 'Artiklar att visa p framsidan');
@define('INSTALL_FETCHLIMIT_DESC', 'Antal artiklar att visa per sida');
@define('IMPORT_ENTRIES', 'Importera data');
@define('EXPORT_ENTRIES', 'Exportera artiklar');
@define('IMPORT_WELCOME', 'Vlkommen till Serendipitys importfunktion');
@define('IMPORT_WHAT_CAN', 'Hr kan du importera artiklar frn andra applikationer');
@define('IMPORT_SELECT', 'Ange applikationen du vill importera frn');
@define('IMPORT_PLEASE_ENTER', 'Ange data enligt nedan');
@define('IMPORT_NOW', 'Importera nu!');
@define('IMPORT_STARTING', 'Startar importen...');
@define('IMPORT_FAILED', 'Import misslyckad');
@define('IMPORT_DONE', 'Importen gick bra');
@define('IMPORT_WEBLOG_APP', 'Webblogg-applikation');
@define('IMPORT_NOTES', 'Anteckning:');
@define('EXPORT_FEED', 'Exportera fullstndig RSS-matning');
@define('STATUS', 'Status efter import');
@define('IMPORT_GENERIC_RSS', 'Generell RSS-import');
@define('ACTIVATE_AUTODISCOVERY', 'Skicka trackbacks till lnkar funna i artikeln');
@define('WELCOME_TO_ADMIN', 'Vlkommen till Serendipitys administrationssidor.');
@define('PLEASE_ENTER_CREDENTIALS', 'Ange dina inloggningsuppgifter nedan.');
@define('ADMIN_FOOTER_POWERED_BY', 'Driven av Serendipity %s och PHP %s');##
@define('INSTALL_USEGZIP', 'Anvnd gzip-komprimerade sidor');
@define('INSTALL_USEGZIP_DESC', 'Fr att snabba upp sidvisning kan sidorna komprimeras innan de skickas till beskaren (om hans/hennes webblsare stdjer detta). Rekommenderas!');
@define('INSTALL_SHOWFUTURE', 'Visa framtida artiklar');
@define('INSTALL_SHOWFUTURE_DESC', 'r alternativet valt kommer postdaterade artiklar att visas i din blogg. Standardinstllningen r att dlja dessa artiklar och inte visa dem innan publiceringsdatumet intrtt.');
@define('INSTALL_DBPERSISTENT', 'Anvnd ihllande anslutning');
@define('INSTALL_DBPERSISTENT_DESC', 'Sl p anvndning av ihllande <a href="http://se.php.net/manual/sv/features.persistent-connections.php" target="_blank">databasanslutningar</a>. Rekommenderas normalt inte');
@define('NO_IMAGES_FOUND', 'Inga bilder hittades');
@define('PERSONAL_SETTINGS', 'Personliga instllningar');
@define('REFERER', 'Hnvisare');
@define('NOT_FOUND', 'Ej hittad');
@define('WRITABLE', 'Skrivbar');
@define('NOT_WRITABLE', 'Ej skrivbar');
@define('PROBLEM_DIAGNOSTIC', 'Du inte fortstta med installationen tills felen ovan har tgrdats');
@define('SELECT_INSTALLATION_TYPE', 'Vlj vilken typ av installation du vill anvnda');
@define('WELCOME_TO_INSTALLATION', 'Vlkommen till Serendipitys installation');
@define('FIRST_WE_TAKE_A_LOOK', 'Undersker din nuvarande installation och frsker diagnostisera kompatibilitetsproblem');
@define('ERRORS_ARE_DISPLAYED_IN', 'Fel visas i %s, rekommendationer i %s och framgng i %s');
@define('RED', 'rd');
@define('YELLOW', 'gul');
@define('GREEN', 'grn');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s frinstallationsrapport');
@define('RECOMMENDED', 'Rekomenderad');
@define('ACTUAL', 'Verklig');
@define('PHPINI_CONFIGURATION', 'php.ini-konfiguration');
@define('PHP_INSTALLATION', 'PHP-installation');
@define('THEY_DO', 'they do');
@define('THEY_DONT', 'they do not');
@define('SIMPLE_INSTALLATION', 'Enkel installation');
@define('EXPERT_INSTALLATION', 'Expertinstallation');
@define('COMPLETE_INSTALLATION', 'Komplett installation');
@define('WONT_INSTALL_DB_AGAIN', 'Kommer inte att installera databasen igen');
@define('CHECK_DATABASE_EXISTS', 'Kollar om databasen och tabellerna redan finns');
@define('CREATING_PRIMARY_AUTHOR', 'Skapar huvudfrfattare \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Anger standardmall');
@define('INSTALLING_DEFAULT_PLUGINS', 'Installerar standardinsticksmoduler');
@define('SERENDIPITY_INSTALLED', 'Serendipity har installerats');
@define('VISIT_BLOG_HERE', 'Besk din nya blogg hr');
@define('THANK_YOU_FOR_CHOOSING', 'Tack fr att du valde Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Ett fel upptcktes i installationen');
@define('OPERATING_SYSTEM', 'Operativsystem');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('TEMPLATE_SET', '\'%s\' har valts som din aktiva mall');
@define('SEARCH_ERROR', 'Skfunktionen fungerade inte som vntat. Meddelande till bloggens administratr: Kan bero p saknade indexnycklar i din databas. P MySQL-system mste databasens anvndare ha rtt att utfra fljande kommando: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Felet som returnerades av databasen var: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'Redigerar "%s"');
@define('CATEGORY_REMAINING', 'Ta bort denna kategori och flytta dessa artiklar till denna kategori');
@define('CATEGORY_INDEX', 'Nedan r en lista med kategorier tillgngliga fr dina artiklar');
@define('NO_CATEGORIES', 'Inga kategorier');
@define('RESET_DATE', 'terstllningsdatum');
@define('RESET_DATE_DESC', 'Klicka hr fr att terstlla datumet till den nuvarande tiden');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Rttigheter kan stllas in genom att kra fljande shellkommando: `<em>%s</em>` p katalogen som misslyckades, eller genom att stlla in detta med ett FTP-program');
@define('WARNING_TEMPLATE_DEPRECATED', 'Varning: Din nuvarande mall r frldrad. Du br updatera den om mjligt');
@define('ENTRY_PUBLISHED_FUTURE', 'Denna artikel r nnu ej publicerad.');
@define('ENTRIES_BY', 'Artiklar av %s');
@define('PREVIOUS', 'Fregende');
@define('NEXT', 'Nsta');
@define('APPROVE', 'Godknn');
@define('DO_MARKUP_DESCRIPTION', 'Applicera frkortad textdekoration (smilies, snabbformatering med *, /, _, ...). Att avvaktivera detta kommer att bevara all HTML-kod i texten.');
@define('CATEGORY_ALREADY_EXIST', 'En kategori med namnet "%s" finns redan');
@define('ERROR_FILE_FORBIDDEN', 'Du har inte tilltelse att ladda upp filer med krbart innehll (t.ex. skript etc)');
@define('ADMIN', 'Administration');
@define('ADMIN_FRONTPAGE', 'Framsida');
@define('QUOTE', 'Citat');
@define('IFRAME_SAVE', 'Serendipity sparar din artikel, skapar trackbacks och utfr eventualla XML-RPC-anrop. Det kan ta lite tid...');
@define('IFRAME_SAVE_DRAFT', 'Ett utkast till denna artikel har sparats');
@define('IFRAME_PREVIEW', 'Serendipity skapar frhandsgranskning av din artikel...');
@define('IFRAME_WARNING', 'Din webblsare stder inte iframes. ppna filen serendipity_config.inc.php och stt variabeln $serendipity[\'use_iframe\'] till FALSE.');
@define('NONE', 'ingen');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Normalinstllningar fr nya artiklar');
@define('UPGRADE', 'Uppgradera');
@define('UPGRADE_TO_VERSION', 'Uppgradera till version %s');
@define('DELETE_DIRECTORY', 'Ta bort katalog');
@define('DELETE_DIRECTORY_DESC', 'Du r p vg att ta bort en katalog som innehller mediafiler vilka  ev. anvnds i dina artiklar.');
@define('FORCE_DELETE', 'Ta bort ALLA filer i denna katalog, inklusive dem som inte r knda av Serendipity');
@define('CREATE_DIRECTORY', 'Skapa katalog');
@define('CREATE_NEW_DIRECTORY', 'Skapa ny katalog');
@define('CREATE_DIRECTORY_DESC', 'Hr kan du skapa en ny katalog att lgga mediafiler i. Vlj ett namn fr din nya katalog och ange en eventuell katalog att placera den i.');
@define('BASE_DIRECTORY', 'Baskatalog');
@define('USERLEVEL_EDITOR_DESC', 'Standardredaktr');
@define('USERLEVEL_CHIEF_DESC', 'Chefredaktr');
@define('USERLEVEL_ADMIN_DESC', 'Administratr');
@define('USERCONF_USERLEVEL', 'Accessniv');
@define('USERCONF_USERLEVEL_DESC', 'Denna niv anvnds fr att bestmma vilken slags tillgng denna anvndare ska ha till bloggen');
@define('USER_SELF_INFO', 'Inloggad som %s (%s)');
@define('ADMIN_ENTRIES', 'Artiklar');
@define('RECHECK_INSTALLATION', 'Kolla installationen igen');
@define('IMAGICK_EXEC_ERROR', 'Kunde inte utfra: "%s", fel: %s, retur var: %d');
@define('INSTALL_OFFSET_DESC', 'Ange antal timmar mellan tiden p din webbserver (nuvarande: %clock%) och din nskade tidszon');
@define('UNMET_REQUIREMENTS', 'Kraven uppfylldes ej: %s');
@define('CHARSET', 'Teckenuppsttning');
@define('AUTOLANG', 'Anvnd beskarens webblsarsprk som standardinstllning');
@define('AUTOLANG_DESC', 'Om aktiverat, kommer beskarens sprkinstllning att avgra standardinstllning fr sprk p din artikel och fr grnssnittssprket.');
@define('INSTALL_AUTODETECT_URL', 'Knn igen HTTP-vrd automatiskt');
@define('INSTALL_AUTODETECT_URL_DESC', 'Om satt till "true", kommer Serendipity se till att den HTTP-vrd som anvndes av din beskare r din BaseURL-instllning. Om du aktiverar detta kommer du att kunna anvnda flera domnnamn fr din Serendipity Blogg och anvnda den domnen fr uppfljande lnkar som anvndaren anvnde fr att f tillgng till din blogg.');
@define('CONVERT_HTMLENTITIES', 'Frsk auto-konvertera HTML-entiteter?');
@define('EMPTY_SETTING', 'Du angav ett ogiltigt vrde fr "%s"!');
@define('USERCONF_REALNAME', 'Riktigt namm');
@define('USERCONF_REALNAME_DESC', 'Frfattarens hela namn. Detta namn ses av lsarna');
@define('HOTLINK_DONE', 'Filen lnkad.<br />Klar.');
@define('ENTER_MEDIA_URL_METHOD', 'Hmtningsmetod:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Kommentar: Om du vljer att lnka till en server br du frskra dig om att du har tillstnd att lnka till den aktuella webbplatsen, eller att webbplatsen r din egen. Lnkning lter dig anvnda bilder p andra webbplatser utan att behva frvara dem lolalt.');
@define('MEDIA_HOTLINKED', 'lnkad');
@define('FETCH_METHOD_IMAGE', 'Ladda ner bild till servern');
@define('FETCH_METHOD_HOTLINK', 'Lnka till server');
@define('DELETE_HOTLINK_FILE', 'Ta bort den lnkade filen <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Visa e-postadresser?');
@define('IMAGE_MORE_INPUT', 'Lgg till fler bilder');
@define('BACKEND_TITLE', 'Mer information p instllningsidan fr insticksmoduler');
@define('BACKEND_TITLE_FOR_NUGGET', 'Hr kan du definiera en valfri strng som kommer att visas p instllningssidan fr insticksmoduler tillsammans med beskrivningen av insticksmodulen HTML Nugget. Om du har flera HTML Nugget-insticksmoduler med en tom titel hjlper detta fr att gra skilja dem frn varandra.');
@define('CATEGORIES_ALLOW_SELECT', 'Tillt beskare att visa flera kategorier samtidigt?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Om detta alternativ r valt kommer en kryssruta att visas bredvid varje kategori i denna sidomeny. Anvndare kan kryssa i dessa rutor och sedan se artiklar tillhrande detta urval.');
@define('PAGE_BROWSE_PLUGINS', 'Sida %s av %s, totalt %s insticksmoduler.');
@define('INSTALL_CAT_PERMALINKS', 'Permalinks');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Definierar diverse URL-mnster fr skapa permanenta lnkar i din blogg. Det rekommenderas att du anvnder de frinstllda vrdena; om inte br du frska att anvnda %id%-vrdet dr det r mjligt fr att frhindra att Serendipity frgar databasen efter ml-URLen.');
@define('INSTALL_PERMALINK', 'Artiklars permalink-URL-struktur');
@define('INSTALL_PERMALINK_DESC', 'Hr kan du definiera URL-strukturen relativt till din bas-URL fr att n dina artiklar. Du kan anvnda variablerna %id%, %title%, %day%, %month%, %year% samt alla andra tecken.');
@define('INSTALL_PERMALINK_AUTHOR', 'Frfattares artiklars pemalink-URL-struktur');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Hr kan du definiera URL-strukturen relativt till din bas-URL fr att n artiklar skrivna av vissa frfattare. Du kan anvnda variablerna %id%, %realname%, %username%, %email% samt alla andra tecken.');
@define('INSTALL_PERMALINK_CATEGORY', 'Kategoriers permalink-URL-struktur');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hr kan du definiera URL-strukturen relativt till din bas-URL fr att n artiklar i vissa kategorier. Du kan anvnda variablerna %id%, %name%, %description% samt alla andra tecken.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Kategoriers RSS-matningars permalink-URL-struktur');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Hr kan du definiera URL-strukturen relativt till din bas-URL fr att n RSS-matningar frn vissa kategorier. Du kan anvnda variablerna %id%, %name%, %description% samt alla andra tecken.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Skvg till arkiv');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Skvg till arkiv');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Skvg till kategorier');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Skvg till avbestll kommentarer');
@define('INSTALL_PERMALINK_DELETEPATH', 'Skvg till ta bort kommentarer');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Skvg till godknn kommentarer');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Skvg till RSS-matningar');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Skvg till enstaka insticksmodul');
@define('INSTALL_PERMALINK_ADMINPATH', 'Skvg till administration');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Skvg till sk');
@define('INSTALL_CAL', 'Kalendertyp');
@define('INSTALL_CAL_DESC', 'Vlj nkskat kalenderformat');
@define('REPLY', 'Svara');
@define('USERCONF_GROUPS', 'Gruppmedlemskap');
@define('USERCONF_GROUPS_DESC', 'Denna anvndare r medlem av fljande grupper. Flera medlemskap r mjliga.');
@define('MANAGE_GROUPS', 'Hantera grupper');
@define('DELETED_GROUP', 'Grupp #%d %s borttagen.');
@define('CREATED_GROUP', 'En ny grupp %s har skapats');
@define('MODIFIED_GROUP', 'Grupp %s egenskaper har ndrats');
@define('GROUP', 'Grupp');
@define('CREATE_NEW_GROUP', 'Skapa ny grupp');
@define('DELETE_GROUP', 'Du hller p att ta bort grupp #%d %s. r du sker?');
@define('USERLEVEL_OBSOLETE', 'NOTERA: Anvndarnivattributet anvnds nu endast fr baktkompatibilitet med insticksmoduler och reservauktorisering. Anvndarprivilegier hanteras nu genom gruppmedlemskap!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner-ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'ID fr matningen som du vill publicera');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurnerbild');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Namn p bild att visa (eller lmna blankt fr rknare), lokaliserad p feedburner.com, exempel: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurnertitel');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Titel (om ngon) att visa tillsammans med bilden');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner bildtext');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Text (om ngon) att visa nr muspekaren hlls ver bilden');
@define('SEARCH_TOO_SHORT', 'Ditt skord mste vara lngre n 3 bokstver. Du kan frska att lgga till * till kortare ord, till exempel s9y* fr att lura skfunktionen.');
@define('INSTALL_DBPORT', 'Databasport');
@define('INSTALL_DBPORT_DESC', 'Port som anvnds fr att ansluta till din databasserver');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Anvndargrnssnitt: External Services');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Anvndargrnssnitt: Funktioner');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Anvndargrnssnitt: Fullprogram'); // AAAAAAAAAAHHH
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Anvndargrnssnitt: Vyer');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Anvndargrnssnitt: Artikelrelaterade');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Administrationsgrnssnitt: Editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Administrationsgrnssnitt: Usermanagement');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Administrationsgrnssnitt: Meta information');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Administrationsgrnssnitt: Templates');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Administrationsgrnssnitt: Features');
@define('PLUGIN_GROUP_IMAGES', 'Bilder');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Textdekoration');
@define('PLUGIN_GROUP_STATISTICS', 'Statistik');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Tillg personliga instllningar');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: ndra anvndarniv');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: ndra "Frbjud skapa artiklar"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: ndra rtt att publicera artiklar');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Tillg systeminstllningar');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Tillg blogg-centrerade instllningar');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrativa artiklar');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administrera andra anvndares artiklar');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Importera artiklar');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrera kategorier');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrera andra anvndares kategorier');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Ta bort kategorier');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrera anvndare');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Ta bort anvndare');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: ndra anvndarniv');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrera anvndare i din(a) grupp(er)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrera anvndare som inte r i din(a) grupp(er)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Skapa nya anvndare');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrera anvndargrupper');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrera insticksmoduler');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrera andra anvndares insticksmoduler');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrera mediafiler');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrera mediakataloger');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Lgg till nya mediafiler');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Ta bort mediafiler');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrera andra anvndares mediafiler');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Visa mediafiler');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Synkronisera miniatyrbilder');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrera kommentarer');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrera mallar');
@define('INSTALL_BLOG_EMAIL', 'Bloggens e-postadress');
@define('INSTALL_BLOG_EMAIL_DESC', 'Stller in den e-postadress som anvnds som avsndare i utgende meddelanden. Frskra dig om att anvnda en adress som e-postservern p din vrddator knner igen - mnga e-postservrar avfrdar meddelanden som har en oknd avsndaradress.');
@define('CATEGORIES_PARENT_BASE', 'Visa endast kategorier under...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Du kan vlja en verordnad kategori s att endast dess underordnade kategorier visas.');
@define('CATEGORIES_HIDE_PARALLEL', 'Gm kategorier som inte r en del av kategoritrdet.');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Om du vill gmma kategorier som r dela av ett annat kategoritrd mste du vlja detta. Denna funktion r mest anvndbar i samband med en multi-blogg som anvnder "Properties/Tempaltes of categories"-insticksmodulen.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Visa andra anvndares mediafiler');
@define('CHARSET_NATIVE', 'Inneboende');
@define('INSTALL_CHARSET', 'Tangentuppsttningsval');
@define('INSTALL_CHARSET_DESC', 'Hr kan du vlja UTF-8 eller inneboende (ISO, EUC, ...) tangentuppsttning. Vissa sprk har endast UTF-8-versttningar och att vlja tangentuppsttningen "Inneboende" har d ingen effekt. UTF-8 rekommenderas vid nyinstallation. ndra inte denna instllning om du redan har skrivit artiklar med specialtecken - detta kan leda till korrupta tecken. Ls vnligen mer om detta p http://www.s9y.org/index.php?node=46 .');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Aktivera insticksmodulers API hook');
@define('CALENDAR_EXTEVENT_DESC', 'Om detta akiveras kan insticksmoduler koppla in sig i kalendern fr att visa sina egna hndelser p ett framtrdande stt. Aktivera endast om du har installerat insticksmoduler som behver detta, annars kommer det endast att medfra lgre prestanda.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API grnssnittet till Serendipity inkluderas inte lngre p grund av innevarande skerhetsproblem med detta API samt att f anvnder det. Drfr behver du installera XML-RPC-insticksmoduken fr att anvnda XML-RPC API:t. URL:en som anvnds i din applikation kommer inte att ndras - s snart du har installerat insticksmodulen kommer du terigen att kunna anvnda API:t.');
@define('PERM_READ', 'Lstillstnd');
@define('PERM_WRITE', 'Skrivtillstnd');
@define('PERM_DENIED', 'Tillstnd nekas.');
@define('INSTALL_ACL', 'Anvnd lstillstnd fr kategorier');
@define('INSTALL_ACL_DESC', 'Om detta aktiveras kommer anvndargruppstillstnden som du anger fr kategorier att tillmpas nr inloggade anvndare besker din blogg. Om detta inaktiveras kommer lstillstnden fr kategorier INTE att anvndas, men den positiva effekten r en liten uppsnabbning p din blogg. Allts, om du inte behver fleranvndarlsrttigheter fr din blogg kan du inaktivera denna instllning.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Instllningssyntax fel fr instllningen "%s". Innehll av typen "%s" behvs.');
@define('USERCONF_CHECK_PASSWORD', 'Gammalt lsenord');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Om du ndrar lsenordet i fltet ovean mste du fylla i det nuvarande lsenordet i det hr fltet.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Du har inte angett det gamla lsenordet p korrekt stt och du har drfr inte tillstnd att ndra lsenord. Dina instllningar sparades inte.');
@define('ERROR_XSRF', 'Din webblsre skickade inte en giltig HTTP-hnvisarstrng. Detta kan ha orsakats av en felkonfigurerad webblsare/proxy eller av en Cross Site Request Forgery (XSRF) riktad mot dig. Den efterfrgade handlingen kunde inte genomfras.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Hr kan du definiera URL-strukturen relativt till din bas-URL fr att n RSS-matningar frn vissa frfattare. Du kan anvnda variablerna %id%, %realname%, %username%, %email% och alla andra tecken.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Frfattares RSS-matningars permalink-URL-struktur');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Skvg till frfattare');
@define('AUTHORS', 'Frfattare');
@define('AUTHORS_ALLOW_SELECT', 'Tillt beskare att visa flera frfattare samtidigt?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Om detta alternativ r valt kommer en kryssruta att visas bredvid varje frfattare i denna sidomeny. Anvndare kan kryssa i dessa rutor och sedan se artiklar tillhrande detta urval.');
@define('AUTHOR_PLUGIN_DESC', 'Visar en lista med frfattare');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Aktivera Smarty-mallar?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'OM detta alternativ r valt kommer insticksmodulen att anvnda Smarty-mallafunktioner fr att skriva ut kategorilistan. Om du vljer detta kan du ndra layouten genom mallfilen "plugin_categories.tpl". Att anvnda denna funtion pverkekar prestandan s lt den vara inaktiv om du inte behver gra specialanpassningar.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Visa antalet artiklar i varje kategori?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Visa antalet artiklar bredvid frfattarens namn?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Om detta alternativ r valt kommer antalet artiklar av denna frfattare att visas bredvid frfattarens namn inom parantes.');
@define('CUSTOM_ADMIN_INTERFACE', 'Personligt administrationsgrnssnitt tillgnligt');

@define('COMMENT_NOT_ADDED', 'Din kommentar kunde inte lggas till drfr att antingen s r kommentarer inte tilltna fr denna artikel, det du skrev var inte tilltet eller s filtrerade anti-spam filtret det. ');
@define('INSTALL_TRACKREF', 'Vill du sl p referrer tracking?');
@define('INSTALL_TRACKREF_DESC', 'Genom att sl p referrer tracking s ser du vilka webbplatser som refererar till dina artiklar. Det utnyttjas ofta av spammare s du kan vlja att inte ha det pslaget.');
@define('CATEGORIES_HIDE_PARENT', 'Vill du gmma vald verordnad kategori?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Om du begrnsar listningen av kategorier till en specifik kategori s kommer du att endast se den verordnade kategorin nr de listas. Om du avaktiverar detta val s kommer inte den verordnade kategorin att visas.');
@define('WARNING_NO_GROUPS_SELECTED', 'OBS! Du valde inte ngot gruppmedlemskap. Det medfr att du kommer att loggas ut frn hanteringen av anvndargrupper. Ditt medlemskap har drfr inte ndrats.');
@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
@define('FURTHER_LINKS', 'Further Links');
@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Comment removed)');

@define('CURRENT_AUTHOR', 'Current author');

@define('WORD_NEW', 'New');
@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
@define('MEDIA_KEYWORDS', 'Media keywords');
@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
@define('MEDIA_PROP', 'Media properties');


@define('GO_ADD_PROPERTIES', 'Go & enter properties');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
@define('MEDIA_PROPERTY_TITLE', 'Title');
@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');

@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Theme/Style options');

@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');

@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Associated Date');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');

@define('MEDIA_TARGET', 'Target for this link');
@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
@define('MEDIA_ENTRY', 'Isolated Entry');
@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');

@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
@define('PLUGIN_ACTIVE', 'Active');
@define('PLUGIN_INACTIVE', 'Inactive');
@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');

@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
